logger

package module
v1.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 15, 2023 License: Apache-2.0 Imports: 6 Imported by: 0

README

logger

Documentation

Overview

logger provides a consistent logging implementation for use across WeMoney back end services

Index

Constants

const (
	DebugLevel = zerolog.DebugLevel
	InfoLevel  = zerolog.InfoLevel
	WarnLevel  = zerolog.WarnLevel
	ErrorLevel = zerolog.ErrorLevel
	FatalLevel = zerolog.FatalLevel
	PanicLevel = zerolog.PanicLevel
	NoLevel    = zerolog.NoLevel
	Disabled   = zerolog.Disabled
	TraceLevel = zerolog.TraceLevel
)

Variables

This section is empty.

Functions

This section is empty.

Types

type Level

type Level = zerolog.Level

type Logger

type Logger struct {
	// contains filtered or unexported fields
}

func New

func New(isDebug bool) *Logger

func (*Logger) Ctx

func (l *Logger) Ctx(ctx context.Context) *Logger

Ctx returns the Logger associated with the ctx. If no logger is associated, a disabled logger is returned.

func (*Logger) Debug

func (l *Logger) Debug() *zerolog.Event

Debug starts a new message with debug level.

You must call Msg on the returned event in order to send the event.

func (*Logger) DebugWithReqID

func (l *Logger) DebugWithReqID(ctx context.Context) *zerolog.Event

DebugWithReqID starts a new message with debug level after injecting the reqID to the log

func (*Logger) Error

func (l *Logger) Error() *zerolog.Event

Error starts a new message with error level.

You must call Msg on the returned event in order to send the event.

func (*Logger) ErrorWithReqID

func (l *Logger) ErrorWithReqID(ctx context.Context) *zerolog.Event

Error starts a new message with error level after injecting the reqID to the log

func (*Logger) Fatal

func (l *Logger) Fatal() *zerolog.Event

Fatal starts a new message with fatal level. The os.Exit(1) function is called by the Msg method.

You must call Msg on the returned event in order to send the event.

func (*Logger) FatalWithReqID

func (l *Logger) FatalWithReqID(ctx context.Context) *zerolog.Event

Fatal starts a new message with fatal level after injecting the reqID to the log

func (*Logger) Hook

func (l *Logger) Hook(h zerolog.Hook) zerolog.Logger

Hook returns a logger with the h Hook.

func (*Logger) Info

func (l *Logger) Info() *zerolog.Event

Info starts a new message with info level.

You must call Msg on the returned event in order to send the event.

func (*Logger) InfoWithReqID

func (l *Logger) InfoWithReqID(ctx context.Context) *zerolog.Event

InfoWithReqID starts a new message with info level after injecting the reqID to the log

func (*Logger) Level

func (l *Logger) Level(level zerolog.Level) zerolog.Logger

Level creates a child logger with the minimum accepted level set to level.

func (*Logger) Log

func (l *Logger) Log() *zerolog.Event

Log starts a new message with no level. Setting zerolog.GlobalLevel to zerolog.Disabled will still disable events produced by this method.

You must call Msg on the returned event in order to send the event.

func (*Logger) Output

func (l *Logger) Output(w io.Writer) zerolog.Logger

Output duplicates the global logger and sets w as its output.

func (*Logger) Panic

func (l *Logger) Panic() *zerolog.Event

Panic starts a new message with panic level. The message is also sent to the panic function.

You must call Msg on the returned event in order to send the event.

func (*Logger) PanicWithReqID

func (l *Logger) PanicWithReqID(ctx context.Context) *zerolog.Event

Panic starts a new message with panic level after injecting the reqID to the log

func (*Logger) Print

func (l *Logger) Print(v ...interface{})

Print sends a log event using debug level and no extra field. Arguments are handled in the manner of fmt.Print.

func (*Logger) Printf

func (l *Logger) Printf(format string, v ...interface{})

Printf sends a log event using debug level and no extra field. Arguments are handled in the manner of fmt.Printf.

func (*Logger) Sample

func (l *Logger) Sample(s zerolog.Sampler) zerolog.Logger

Sample returns a logger with the s sampler.

func (*Logger) Warn

func (l *Logger) Warn() *zerolog.Event

Warn starts a new message with warn level.

You must call Msg on the returned event in order to send the event.

func (*Logger) WarnWithReqID

func (l *Logger) WarnWithReqID(ctx context.Context) *zerolog.Event

Warn starts a new message with warn level after injecting the reqID to the log

func (*Logger) With

func (l *Logger) With() zerolog.Context

With creates a child logger with the field added to its context.

func (*Logger) WithLevel

func (l *Logger) WithLevel(level zerolog.Level) *zerolog.Event

WithLevel starts a new message with level.

You must call Msg on the returned event in order to send the event.

Jump to